#!/bin/sh
BOLD=$(tput bold)
NORMAL=$(tput sgr0)
DINIT_VER=$(dinit --version | grep version)

cat /etc/issue | grep KaOS > /dev/null
if [ $? -eq 0 ]; then
  OS=KaOS
else
  OS=UNKNOWN
fi

echo ""
echo "${BOLD}Welcome to $OS GNU/Linux!${NORMAL}"
echo "${BOLD}$DINIT_VER${NORMAL} is now booting up"
echo ""
